@@ -6,7 +6,7 @@
 # <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
 #
 # FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
-# t.me/AyiinXdSupport & t.me/AyiinSupport
+# t.me/AyiinChat & t.me/AyiinSupport
 
 
 # ========================×========================
@@ -17,7 +17,7 @@ class Queue(object):
     def __init__(self):
         self.queue = {}
 
-    def add_to_queue(chat_id, songname, link, ref, type, quality):
+    def add_to_queue(self, chat_id, songname, link, ref, type, quality):
         if chat_id in self.queue:
             chat_queue = self.queue[chat_id]
             chat_queue.append([songname, link, ref, type, quality])
@@ -25,13 +25,13 @@ class Queue(object):
         self.queue[chat_id] = [[songname, link, ref, type, quality]]
     
     
-    def get_queue(chat_id):
+    def get_queue(self, chat_id):
         if chat_id in self.queue:
             return self.queue[chat_id]
         return 0
     
     
-    def pop_an_item(chat_id):
+    def pop_an_item(self, chat_id):
         if chat_id not in self.queue:
             return 0
     
@@ -40,7 +40,7 @@ class Queue(object):
         return 1
     
     
-    def clear_queue(chat_id: int):
+    def clear_queue(self, chat_id: int):
         if chat_id not in self.queue:
             return 0
     
